@@ -6,18 +6,12 @@
     # Get the list of optimized packages for a given architecture
     # Before removing a package from this list, make sure it appears
     # in the Conflicts: line of libc.
-    case $(dpkg --print-architecture) in
+    case ${DPKG_MAINTSCRIPT_ARCH} in
         alpha)
             hwcappkgs="libc6-alphaev67"
             ;;
         i386)
-            hwcappkgs="libc6-i686 libc6-xen"
-            ;;
-        kfreebsd-i386)
-            hwcappkgs="libc0.1-i686"
-            ;;
-        sparc)
-            hwcappkgs="libc6-sparcv9 libc6-sparcv9b"
+            hwcappkgs="libc6-xen"
             ;;
     esac
  
